package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````(``P`!`````*8$"#0```!`H@```````#0`(``,
M`"@`'0`<``8````T````-(`$"#2`!`B``0``@`$```0````$`````P```+0!
M``"T@00(M($$"!,````3````!`````$````!``````````"`!`@`@`0(_!``
M`/P0```$`````!````$`````(````*`$"`"@!`AT+P``="\```4`````$```
M`0````!0````T`0(`-`$"!1%```410``!``````0```!````R)X``,@N!0C(
M+@4(/`(``(P2```&`````!````(```#DG@``Y"X%".0N!0@(`0``"`$```8`
M```$````!````,@!``#(@00(R($$"'@```!X````!`````0```!3Y71D[`$`
M`.R!!`CL@00(-````#0````$````!````%#E=&0PCP``,`\%"#`/!0C4````
MU`````0````$````4>5T9```````````````````````````!@```!````!2
MY71DR)X``,@N!0C(+@4(.`$``#@!```$`````0```"]L:6(O;&0M;&EN=7@N
M<V\N,@``!````!0````#````1TY5`')8:S[TU2',&)(4>Q3B74'<%RY>!```
M`"0````%````1TY5``*``,`$`````0````$``<`$`````0````(``<`$````
M`0````0````0`````0```$=.50```````P````(`````````$0```#T````(
M````"``````<``0E0`2"*`$``:"&`8C``0`"2R@$*#B",D.*``0(/0```#X`
M``!!````1````$4```!,````3@```%````!3````5`````````!5````6```
M`%D```!:``````````````![\$IK;L7?'\[>1RUK?YI\+L6;MM1DU'PA_^0.
MV7%8'.)'Q@&R`8MOK$OCP,+E/RRZXY)\\MO3'?NA;&!J"4/6A_F<@6:OS&;%
MN9Q`./*+'$)%U>R)!W#3R=6R<3-BV^T,.I<+6.CM[*?=HVM_J9R;X:<""@J*
M$%>CX/M)`````````````````````+$"`````````````!(````K`@``````
M```````2````)0(`````````````$@```,X``````````````!(```!@````
M```````````2````%P(`````````````$@```%4!`````````````!(```#4
M`0`````````````2````40(`````````````$@````$``````````````"``
M```[`@`````````````2````AP(`````````````$@```-0"````````````
M`!(````5`0`````````````2````@0``````````````$@````4!````````
M`````!(```#W```````````````2`````P(`````````````$@```/X!````
M`````````!(```!S`0`````````````2````TP``````````````$@```*,"
M`````````````!(```!@`@`````````````2````E`(`````````````$@``
M`!```````````````!(````M```````````````6````O0``````````````
M$@```%$``````````````!(```"Z`0`````````````2````\0$`````````
M````$@```-L!`````````````!(```"7`P`````````````2````H0``````
M````````$@```)P"`````````````!(````W`0`````````````2````RP$`
M````````````$@```(X"`````````````!(````I`0`````````````2````
M$`(`````````````$@```&P!`````````````!(```#8```````````````2
M````G`$`````````````$@```/@!`````````````!(```#J`0``````````
M```2````7P(`````````````$@```#("`````````````!(```#B`0``````
M```````2````;```````````````$@```&`!`````````````!(```!#`@``
M```````````2````@`(`````````````$@```,("`````````````!(````>
M`0`````````````2````'@``````````````$@```,0!`````````````!(`
M``!G`@`````````````2````L@$`````````````$@```*H"````````````
M`!(```"M`0`````````````2````CP``````````````$@```$4!``#`H00(
M`````!(```"@`P``-LX$".T````2``X`T@,``.6_!`@]"P``$@`.`'0"````
MI`0(_0$``!(`#@`:`P``>[@$"`4````2``X`/P,``"++!`@4`P``$@`.`/@#
M``"`N`0(Q@$``!(`#@#!`P``(#$%"``````0`!H`*P,``$:Z!`@@````$@`.
M`%4#``")O@0(7````!(`#@"-`0``!-`$"`0````1`!``N0,``'VW!`@O````
M$@`.`,T#``!4004(`````!``&@!^`0``T"X%"!,````1`!4`Y@,``/^^!`CF
M````$@`.`*P#``#T,`4(`````!``&0!`````T*$$"``````2````>0,``&:Z
M!`C`````$@`.`,H"```D,04(!````!$`&@!Y`@``(#$%"`0````1`!H`WP,`
M``0Q!0@`````$``9``4$````,04(!````!$`&0#D````P*`$"``````2````
ML@,```"F!`@R````$@`.`*X#``#T,`4(`````"``&0`X`P```-`$"`0````1
M`!``S`(``"0Q!0@$````(0`:`(4#``#EO@0(&@```!(`#@!C`P``K+<$",\`
M```2``X`L````#`Q!0@!````$0`:``\$```FNP0(8P,``!(`#@``7U]G;6]N
M7W-T87)T7U\`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!03%]C=7)R
M96YT7V-O;G1E>'0`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!0
M97)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V7W-H:69T
M`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M
M<`!097)L7VYE=UA37V9L86=S`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L
M7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`
M<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T
M8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L
M;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``7TE/7W-T9&EN7W5S960`
M7U]S=&%C:U]C:&M?9F%I;`!E>&ET`&QS965K-C0`<F5A9&1I<C8T`'-T<F1U
M<`!C;&]S961I<@!O<&5N-C0`=6YL:6YK`&UE;6UO=F4`<W1R=&]K`'-T<FQE
M;@!R;61I<@!R96%D`%]?;65M8W!Y7V-H:P!S=')S='(`7U]S=')N8W!Y7V-H
M:P!M:V1I<@!G971P:60`<F5A9&QI;FL`<F5A;&QO8P!?7W-P<FEN=&9?8VAK
M`%]?9G!R:6YT9E]C:&L`;'-T870V-`!?7VQI8F-?<W1A<G1?;6%I;@!S=&1E
M<G(`;65M8VAR`'-T<F-H<@!C;&]S90!O<&5N9&ER`&=E='5I9`!A8V-E<W,`
M<W1R8VUP`%]?97)R;F]?;&]C871I;VX`<W1R;F-M<`!?7V5N=FER;VX`7U]R
M96=I<W1E<E]A=&9O<FL`;&EB<&5R;"YS;RXU+C0P+C``;&EB;2YS;RXV`&QI
M8F,N<V\N-@!L:6)C<GEP="YS;RXR`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A
M<V5N86UE`%]F<%]H=P!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C
M;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`9V5T7W5S
M97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7U]D871A7W-T87)T
M`'AS7VEN:70`7U]B<W-?<W1A<G0`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A
M`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R
M7VEN:71?96YV`$=,24)#7S(N,S0`1TQ)0D-?,BXT`$=,24)#7S(N,@!'3$E"
M0U\R+C,S`$=,24)#7S(N,RXR`$=,24)#7S(N,0!'3$E"0U\R+C,N-`!'3$E"
M0U\R+C``+W5S<B]L:6(O<&5R;#4O-2XT,"XP+VDV.#8M<&QD+6QI;G5X+71H
M<F5A9"UM=6QT:2]#3U)%``````(``@`"``$``0`#``$`!``#``$``@`"``4`
M`0`!``$``0`#``(``0`"``(`!@`"``$``0`!``$`!P`"``(``@`!``(``0`"
M``(``0`"``(``0`(``(``@`&``(``@`!``$``P`"``(``0`!``(`"0`$``(`
M`@`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``(``@`!
M``$``0`!``$``0`"``$``0`!``$````!``@``@,``!``````````M)&6!@``
M"0`<!```$````!1I:0T```@`)P0``!`````2:6D-```'`#$$```0````LY&6
M!@``!@`[!```$````'(9:0D```4`1@0``!`````1:6D-```$`%($```0````
M=!EI"0```P!<!```$````!!I:0T```(`:`0```````#L+P4(!@H``/`O!0@.
M&@``T"X%"`5*```@,04(!5```"0Q!0@%3P``,#$%"`5:````,`4(!P$```0P
M!0@'`@``"#`%"`<#```,,`4(!P0``!`P!0@'!0``%#`%"`<&```8,`4(!P<`
M`!PP!0@'"```(#`%"`<)```D,`4(!U,``"@P!0@'"P``+#`%"`<,```P,`4(
M!PT``#0P!0@'#@``.#`%"`</```\,`4(!Q```$`P!0@'$0``1#`%"`<2``!(
M,`4(!Q,``$PP!0@'%```4#`%"`<5``!4,`4(!Q8``%@P!0@'%P``7#`%"`<8
M``!@,`4(!QD``&0P!0@'/0``:#`%"`=-``!L,`4(!QL``'`P!0@''```=#`%
M"`<=``!X,`4(!QX``'PP!0@''P``@#`%"`<@``"$,`4(!R$``(@P!0@'(@``
MC#`%"`<C``"0,`4(!R0``)0P!0@')0``F#`%"`<F``"<,`4(!R<``*`P!0@'
M*```I#`%"`<I``"H,`4(!RH``*PP!0@'*P``L#`%"`<L``"T,`4(!RT``+@P
M!0@'+@``O#`%"`<O``#`,`4(!S```,0P!0@',0``R#`%"`<R``#,,`4(!S,`
M`-`P!0@'-```U#`%"`<U``#8,`4(!S8``-PP!0@'-P``X#`%"`<X``#D,`4(
M!SD``.@P!0@'.@``[#`%"`<[``#P,`4(!SP`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!3@^P(Z#<&``"!P^N/``"+@_C___^%P'0"_]"#Q`A;P_\U^"\%"/\E_"\%
M"`````#_)0`P!0AH`````.G@_____R4$,`4(:`@```#IT/____\E"#`%"&@0
M````Z<#_____)0PP!0AH&````.FP_____R40,`4(:"````#IH/____\E%#`%
M"&@H````Z9#_____)1@P!0AH,````.F`_____R4<,`4(:#@```#I</____\E
M(#`%"&A`````Z6#_____)20P!0AH2````.E0_____R4H,`4(:%````#I0/__
M__\E+#`%"&A8````Z3#_____)3`P!0AH8````.D@_____R4T,`4(:&@```#I
M$/____\E.#`%"&AP````Z0#_____)3PP!0AH>````.GP_O___R5`,`4(:(``
M``#IX/[___\E1#`%"&B(````Z=#^____)4@P!0AHD````.G`_O___R5,,`4(
M:)@```#IL/[___\E4#`%"&B@````Z:#^____)50P!0AHJ````.F0_O___R58
M,`4(:+````#I@/[___\E7#`%"&BX````Z7#^____)6`P!0AHP````.E@_O__
M_R5D,`4(:,@```#I4/[___\E:#`%"&C0````Z4#^____)6PP!0AHV````.DP
M_O___R5P,`4(:.````#I(/[___\E=#`%"&CH````Z1#^____)7@P!0AH\```
M`.D`_O___R5\,`4(:/@```#I\/W___\E@#`%"&@``0``Z>#]____)80P!0AH
M"`$``.G0_?___R6(,`4(:!`!``#IP/W___\EC#`%"&@8`0``Z;#]____)9`P
M!0AH(`$``.F@_?___R64,`4(:"@!``#ID/W___\EF#`%"&@P`0``Z8#]____
M)9PP!0AH.`$``.EP_?___R6@,`4(:$`!``#I8/W___\EI#`%"&A(`0``Z5#]
M____):@P!0AH4`$``.E`_?___R6L,`4(:%@!``#I,/W___\EL#`%"&A@`0``
MZ2#]____);0P!0AH:`$``.D0_?___R6X,`4(:'`!``#I`/W___\EO#`%"&AX
M`0``Z?#\____)<`P!0AH@`$``.G@_/___R7$,`4(:(@!``#IT/S___\ER#`%
M"&B0`0``Z<#\____)<PP!0AHF`$``.FP_/___R70,`4(:*`!``#IH/S___\E
MU#`%"&BH`0``Z9#\____)=@P!0AHL`$``.F`_/___R7<,`4(:+@!``#I</S_
M__\EX#`%"&C``0``Z6#\____)>0P!0AHR`$``.E0_/___R7H,`4(:-`!``#I
M0/S___\E[#`%"&C8`0``Z3#\____)?`P!0AHX`$``.D@_/__58GE5U93@^3P
M@^Q`BT4,B40D+(M%$(E$)"AEH10```")1"0\,<"-1"0HB40D"(U$)"R)1"0$
MC44(B00DZ$_____'1"0(P*`$",=$)`3`H`0(QP0DT*$$".C&*@``@#TP,04(
M``^$``$``*'P+P4(98L`@(BB`@```XM%"(/`!3W___\_#X=.`0```<`!P(D$
M).BJ_O__B<:C1$$%"(M<)"R+`XD&QT8$S-$$"*$`,04(B48(QT8,S]$$",<%
M2$$%"`0```"+?0B#_P%^&XU#!(U6$(T,/P')`<N+"(D*@\`$@\($.<-U\L=$
MO@P`````QT0D$`````")="0,@\<#B7PD",=$)`08MP0(H5!!!0B)!"3H>/O_
M_XG#A<!T=J%0004(B00DZ&7]__^-5"0XN*?0!`CHY@P``(7`=&NA4$$%"(D$
M).@6^___Z&'\__^+1"0\92L%%`````^%F````(G8C67T6UY?7</H\?O__Z-0
M004(A<!T=(D$).AP_/__H?`O!0AEBQ#&@CH%````Z=O^__^A4$$%"(D$).A?
M^___B</I=O___Z%,004(A<!T"HD$).A]*```ZX*-5"0XN%S0!`CH5@P``*-,
M004(A<`/A&?____KV<=$)`30+@4(QP0D5]`$".A$_?__QP0D`0```.CH_?__
MZ-/\__]FD)`Q[5Z)X8/D\%!44N@9````@</DB0``:@!J`%%6C8,Y=O__4.B(
M_?__](L<),/ISOW__\-FD&:09I!FD&:09I"0BQPDP[@$,04(/00Q!0AT'+@`
M````A<!T$U6)Y8/L&,<$)`0Q!0C_T(GL7</#N`0Q!0@M!#$%"(G"P?H"P>@?
M`=#1^'0@N@````"%TG0758GE@^P8B40D!,<$)`0Q!0C_THGL7</#@#TQ,04(
M`'4658GE@^P(Z(K____&!3$Q!0@!B>Q=P\/KI6:09I!FD&:055=64X'L?`$`
M`(G!B40D#&6A%````(F$)&P!```QP(M4@1P/RHE4A"R#P`&#^!!U[HMT)&"+
M;"1DBT0D:(M<)"R+3"0PB4PD"(U4)#3K!(E,)`B+"HG'BT(8,<@Q\#'8T<")
M0CB#P@2)[HG]BUPD"(V\)#0!```YUW74BWPD#(L?BW<$BV\(BT\,BT<0B40D
M'`-$)"P%F7F"6HG:P<(%`=")ZC'*(?*)SS'*`=")="00B?+!R@*)Z3'1B=XA
MV3'IB7PD&(M<)#`!^X'#F7F"6@'+B<'!P04!RXET)`C!S@*)T3'Q(<$QT8EL
M)!0#;"0TB>^!QYEY@EH!^8G=P<4%`>G!R`*)]3'%B>\AWS'W`U0D.('"F7F"
M6@'ZB<W!Q04!ZL'+`HG%,=V)[R'/,<<#="0\@<:9>8):`?Z)U<'%!0'NP<D"
MB=TQS8GO(=<QWP-$)$`%F7F"6@'XB?7!Q04!Z,'*`HG-,=6)[R'W,<\#7"1$
M@<.9>8):`?N)Q<'%!0'KP<X"B=4Q]8GO(<<QUP-,)$B!P9EY@EH!^8G=P<4%
M`>G!R`*)]3'%B>\AWS'W`U0D3('"F7F"6@'ZB<W!Q04!ZL'+`HG%,=V)[R'/
M,<<#="10@<:9>8):`?Z)U<'%!0'NP<D"B=TQS8GO(=<QWP-$)%0%F7F"6@'X
MB?7!Q04!Z,'*`HG-,=6)[R'W,<\#7"18@<.9>8):`?N)Q<'%!0'KP<X"B=4Q
M]8GO(<<QUP-,)%R!P9EY@EH!^8G=P<4%`>G!R`*)]3'%B>\AWS'W`U0D8('"
MF7F"6@'ZB<W!Q04!ZL'+`HG%,=V)[R'/,<<#="1D@<:9>8):`?Z)U<'%!0'N
MP<D"B=TQS8GO(=<QWP-$)&@%F7F"6@'XB?7!Q04!Z,'*`HG-,=6)[R'W,<\#
M7"1L@<.9>8):`?N)Q<'%!0'KP<X"B=4Q]8GO(<<QUP-,)'"!P9EY@EH!^8G=
MP<4%`>G!R`*)]3'%B>\AWS'W`U0D=('"F7F"6@'ZB<W!Q04!ZL'+`HG%,=V)
M[R'/,<<#="1X@<:9>8):`?>)U<'%!0'OP<D"`T0D?`6AZ]ENB=TQS8GN,=8!
MQHGXP<`%`<;!R@(#G"2`````C8.AZ]ENB<LQTS'[`<.)\,'`!0'#B?C!R`(#
MC"2$````C;FAZ]ENB=$QP3'Q`?F)W<'%!0'IP<X"`Y0DB````(VZH>O9;HG"
M,?(QV@'ZB<W!Q04!ZL'+`@.$)(P```"-N*'KV6Z)\#'8,<@!^(G5P<4%`>C!
MR0(#M"20````C;ZAZ]ENB=TQS8GN,=8!_HG%P<4%`>[!R@(#G"24````C;NA
MZ]ENB<LQTS'#`?N)]<'%!0'KP<@"`XPDF````(VYH>O9;HG1,<$Q\0'YB=W!
MQ04!Z<'.`@.4))P```"-NJ'KV6Z)PC'R,=H!^HG-P<4%`>K!RP(#A"2@````
MC;BAZ]ENB?`QV#'(`?B)U<'%!0'HP<D"`[0DI````(V^H>O9;HG=,<V)[C'6
M`?Z)Q<'%!0'NP<H"`YPDJ````(V[H>O9;HG+,=,QPP'[B?7!Q04!Z\'(`@.,
M)*P```"-N:'KV6Z)T3'!,?$!^8G=P<4%`>G!S@(#E"2P````C;JAZ]ENB<(Q
M\C':`?J)S<'%!0'JP<L"`X0DM````(VXH>O9;HGP,=@QR`'XB=7!Q04!Z,')
M`@.T)+@```"-OJ'KV6Z)W3'-B>XQU@'^B<7!Q04![L'*`@.<)+P```"-NZ'K
MV6Z)RS'3,<,!^XGUP<4%`>O!R`(#C"3`````C;FAZ]ENB=$QP3'Q`?F)W<'%
M!0'IP<X"`Y0DQ````(VZH>O9;HG",?(QV@'ZB<W!Q04!ZL'+`@.$),@```"-
MN*'KV6Z)\#'8,<@!^(G5P<4%`>C!R0*)W0G-(=6)WR'/">\#M"3,````@>XD
M0^1P`?>)Q<'%!0'OP<H"B<T)U2'%B<XAU@GN`YPDT````('K)$/D<`'>B?O!
MPP4!WL'(`HG3"<.)W2']B=,APPGK`XPDU````('I)$/D<`'+B?'!P04!R\'/
M`HG!"?F)S2'UB<$A^0GI`Y0DV````('J)$/D<`'1B=K!P@4!T<'.`HGZ"?*)
MU2'=B?HA\@GJ`X0DW````"TD0^1P`<*)R,'`!0'"P<L"B?4)W2'-B?`AV`GH
M`[PDX````('O)$/D<`'XB=7!Q04!Z,')`HG="<TAU8G?(<\)[P.T).0```"!
M[B1#Y'`!_HG%P<4%`>[!R@*)S0G5(<6)SR'7">\#G"3H````@>LD0^1P`?N)
M]<'%!0'KP<@"B=4)Q2'UB=<AQPGO`XPD[````('I)$/D<`'YB=W!Q04!Z<'.
M`HG%"?4AW8G'(?<)[P.4)/````"!ZB1#Y'`!^HG-P<4%`>K!RP*)]0G=(<V)
M]R'?">\#A"3T````+21#Y'`!^(G5P<4%`>C!R0*)W0G-(=6)WR'/">\#M"3X
M````@>XD0^1P`?Z)Q<'%!0'NP<H"B<T)U2'%B<\AUPGO`YPD_````('K)$/D
M<`'[B?7!Q04!Z\'(`HG5"<4A]8G7(<<)[P.,)``!``"!Z21#Y'`!^8G=P<4%
M`>G!S@*)Q0GU(=V)QR'W">\#E"0$`0``@>HD0^1P`?J)S<'%!0'JP<L"B?4)
MW2'-B?<AWPGO`X0D"`$``"TD0^1P`?B)U<'%!0'HP<D"B=T)S2'5B=\ASPGO
M`[0D#`$``('N)$/D<`'^B<7!Q04![L'*`HG-"=4AQ8G/(=<)[P.<)!`!``"!
MZR1#Y'`!^XGUP<4%`>O!R`*)U0G%(?6)UR''">\#C"04`0``@>DD0^1P`?F)
MW<'%!0'IP<X"B<4)]2'=B<<A]PGO`Y0D&`$``('J)$/D<`'ZB<W!Q04!ZL'+
M`@.$)!P!```M*CZ=-8GU,=V)[S'/`<>)T,'`!0''P<D"`[0D(`$``('N*CZ=
M-8G8,<@QT`'PB?W!Q04!Z,'*`HG6`YPD)`$``(V3UL%BRHG+,?,Q^P'3B<+!
MP@4!T\'/`@.,)"@!``"!Z2H^G36)\C'Z,<(!RHG9P<$%`<J)P<')`@.T)"P!
M``"-AM;!8LJ)_3'-B>XQW@'&B=#!P`4!QL'+`@.\)#`!``"![RH^G36)R#'8
M,=`!^(GUP<4%`>C!R@*)UP.,)#0!``"-D=;!8LJ)V3'Y,?$!T8G"P<(%`='!
MS@(#G"0X`0``@>LJ/ITUB?HQ\C'"`=J)R\'#!0':B</!RP(#O"0\`0``C8?6
MP6+*B?4QW8GO,<\!QXG0P<`%`<?!R0(#M"1``0``@>XJ/ITUB=@QR#'0`?")
M_<'%!0'HP<H"B=8#G"1$`0``C9/6P6+*B<LQ\S'[`=.)PL'"!0'3P<\"`XPD
M2`$``('I*CZ=-8GR,?HQP@'*B=G!P04!RHG!P<D"`[0D3`$``(V&UL%BRHG]
M,<V)[C'>`<:)T,'`!0'&P<L"`[PD4`$``('O*CZ=-8G(,=@QT`'XB?7!Q04!
MZ,'*`@.,)%0!``"!Z2H^G36)W3'5B>\Q]P'/B<'!P04!S\'.`@.<)%@!``"!
MZRH^G36)T3'Q,<$!V8G[P<,%`=G!R`(#E"1<`0``@>HJ/ITUB?,QPS'[`=.)
MRL'"!0'3P<\"`[0D8`$``('N*CZ=-8G",?HQR@'RB=W!Q04!ZL')`@.$)&0!
M``"-L-;!8LJ)^#'(,=@!\(G5P<4%`>C!RP*+="0(`[0D:`$``('N*CZ=-0'W
MB<XQWC'6`?Z)Q<'%!0'NBWPD#(DWBW0D$`'PB?Z)1P3!R@*+;"04C00JB4<(
MBWPD&(T$'XE&#(M$)!P!R(E&$(N$)&P!``!E*P44````=0N!Q'P!``!;7E]=
MP^BQ\/__55=64X/L+(E4)!R%P`^$B0```(G&H20Q!0B)1"08A<!T>@^V!H3`
M=`0\/74Y,>V+?"08BQ^%VW0CB6PD"(ET)`2)'"3H"/'__X7`=0:`/"L]="F#
MQP2+'X7;==V)V(/$+%M>7UW#B?&#P0$/M@&$P'0$/#UU\BGQB<WKLXGZBT0D
M&"G"P?H"BT0D'(D0C4T!`<N)V(/$+%M>7UW#,=N)V(/$+%M>7UW#4X'LB```
M`(G#9:$4````B40D?#'`C40D'(E$)`2)'"3H%/#__X7`=32+5"0L@>(`\```
M@?H`0```=`B!^@"@``!U',=$)`0"````B1PDZ&;N__^%P`^4P`^VP.L",<"+
M5"1\92L5%````'4(@<2(````6\/HD.___U575E.![)P```")PV6A%````(F$
M)(P````QP(7;=`6`.P!U'XN$)(P```!E*P44````#X4*`0``@<2<````6UY?
M7<.)'"3H%>[__XG&A<!TTXDT).AG[O__A<`/A*<```"->!.`>!,N=0:`?P$`
M=.&`>!,N#X2C````B1PDZ$[N__^)Q8D\).A$[O__`<6#Q0*)+"3HU^[__XG%
MB7PD%(E<)!#'1"0,"-`$",=$)`C_____QT0D!`$```")!"3H3>___XU$)"R)
M1"0$B2PDZ'WM__^#^/]T$(M$)#PE`/```#T`0```=$Z)+"3H\.W__XDL).@X
M[?__B30DZ,#M__^%P`^%6?___XDT).@@[O__B1PDZ(CN___I!____X!_`2X/
MA5/___^`?P(`#X0@____Z43___^)Z.C#_O__C78`ZZ[H2>[__U575E.#[#R)
MQXG39:$4````B40D+#'`@#H]=0.#PP&)'"3H8NW__XG%C50D*(GXZ&3]__^)
MQH7`#X3.````B00DZ$/M__\YZ`^#K````(M4)"@!T@'2#[8'A,`/A%L!```\
M/0^$4P$``(GX@\`!#[8(A,ET!8#Y/77Q*?B)UHE4)!0#-20Q!0B#Q0(!Q8DL
M).B4[?__B0:%P'1&H20Q!0B+5"04BQ00C4\!#[8'B`(\/70:A,!U!NL4/#UT
M$(/"`8/!`0^V0?^(`H3`=>S&`CTQP`^V#`.(3`(!@\`!A,EU\8M$)"QE*P44
M````#X7=````@\0\6UY?7<,QP`^V%`.(%`:#P`&$TG7RZ]6+#20Q!0B+,87V
M#X2G````,?:)\(/&`8L4L872=?2#P`,!P`'`BQ5`004(A=)U78E,)!S'!4!!
M!0@!````B00DZ-CL__^)1"04A<!TB(T4-@'2B50D"(E4)!B+3"0<B4PD!(D$
M).@C[?__BT0D%*,D,04(BU0D&(M$)!3'1+`$`````(ET)"CIOO[__XE$)`2)
M#"3HI>K__XE$)!2C)#$%"(7`#X0L____C10V`=+KQS'`Z;G^__^X"````#'V
MZ6+____H=>S__U575E.!["P0``")QHG79:$4````B80D'!```#'`QT0D"/\/
M``"-;"0<B6PD!,<$)`[0!`CH?.S__X7`?A")PXU`_X!\'!L`=3F%P'4SB7PD
M"(ET)`2A\"\%"&6+`(D$).APZO__BX0D'!```&4K!10```!U0X'$+!```%M>
M7UW#B<.)7"0(QT0D!"\```")+"3H;^S__X7`=+.)7"0,B6PD"(ET)`2A\"\%
M"&6+`(D$).@OZ___ZZWHN.O__U.#["C'1"0,^-$$",=$)`C`H00(QT0D!!W0
M!`B+'?`O!0AEBP.)!"3H.^S__\=$)!0`````QT0D$*G1!`C'1"0,J=$$",=$
M)`@BRP0(QT0D!#G0!`AEBP.)!"3H:.K__X/$*%O#@^P<QT0D#/C1!`C'1"0(
MP*$$",=$)`0=T`0(H?`O!0AEBP")!"3HV.O__X/$',-75E.![#`@``!EH10`
M``")A"0L(```,<#H=^C__\=$)!09T`0(B40D$,=$)`Q.T`0(QT0D"`$0``#'
M1"0$`0```(U<)"J)'"3H5^O__\=$)`@`$```C;0D*Q```(ET)`2)'"3H_.K_
M_X7`>%J)PXU``8D$).B+ZO__A<!T%8G'@_L$<S3VPP)U)O;#`74>Q@08`(N4
M)"P@``!E*Q44````=2B!Q#`@``!;7E_#I.O?9J7VPP%TV.OTB=G!Z0+SI?;#
M`G3%Z^DQP.O(Z%7J___I+/___U575E.![*P0``"+O"3`$```B[0DQ!```&6A
M%````(F$))P0```QP(UL)#R)ZKA<T`0(Z&CY__^)P\=$)`0O````B3PDZ!?H
M__^%P'0MB?JX9=`$".BN^___B?B+E"2<$```92L5%`````^%4@$``('$K!``
M`%M>7UW#B3PDZ`[I__^)1"0LQT0D!'+0!`B)-"3HVNG__XG&A<!TL8M$)"R#
MP`&)1"0L@#X`#X3$````A=MT%(ET)`2)'"3HD.K__X7`#X2%````B30DZ,#H
M__^`?`;_+W4.@^@!Q@0&`(!\!O\O=/*+3"0L`<@]_P\```^/5____XE\)!C'
M1"04=-`$"(ET)!#'1"0,7]$$",=$)`@`$```QT0D!`$```"-M"2<````B30D
MZ*/I__^);"0$B30DZ-?G__^%P'40BT0D3"4`\```/0"```!T1\=$)`1RT`0(
MQP0D`````.@/Z?__B<:%P`^$XO[__X`^``^%//___X7;=`6`.RYT#[Y:T`0(
MN`$```#I6?___X![`0!TN^OIQT0D!`$```")-"3H7.?__X7`=:6)\KAET`0(
MZ%/Z__^)-"3H9.G__^F:_O__Z(KH__^+1"0$#[80B<&$TG00@\`!@/HO#T3(
M#[80A-)U\(G(PU.#[!B+7"0@A=L/A((```"`.P!T?8D<).B-Y___@^@!`=@Y
MPW()ZR"#Z`$YPW1T@#@O=/0YPW(+9I#K#(/H`3G#=&"`."]U]#G#=0?K58`X
M+W4)@^@!.<-FD'+R*=B-4`*!^@`0``!W4,=$)`P`$```@\`!B40D"(E<)`3'
M!"1`,04(Z)+E__^X0#$%"(/$&%O#QT0D(%K0!`B#Q!A;Z9?H__^`.R]TZL=$
M)"!TT`0(@\086^F!Z/__,<"#Q!A;PU=6@^PT9:$4````B40D+#'`#[<%U-$$
M"&:)1"0*C7PD#+[6T00(N"````")P<'I`O.EJ`)T`F:EC50D!+AVT`0(Z+/V
M__^%P'0EBT0D!`'``<`#!20Q!0B+4`2)$(72=->#P`2+4`2)$(72=?3KR8U4
M)`2X?]`$".A\]O__A<!T)8M$)`0!P`'``P4D,04(BU`$B1"%TG37@\`$BU`$
MB1"%TG7TZ\F-5"0$N(?0!`CH1?;__X7`="6+1"0$`<`!P`,%)#$%"(M0!(D0
MA=)TUX/`!(M0!(D0A=)U].O)C50D!+B0T`0(Z`[V__^%P'0EBT0D!`'``<`#
M!20Q!0B+4`2)$(72=->#P`2+4`2)$(72=?3KR8U4)`2XE]`$".C7]?__A<!T
M)8M$)`0!P`'``P4D,04(BU`$B1"%TG37@\`$BU`$B1"%TG7TZ\F-5"0$N*?0
M!`CHH/7__X7`="6+1"0$`<`!P`,%)#$%"(M0!(D0A=)TUX/`!(M0!(D0A=)U
M].O)C50D!+A<T`0(Z&GU__^%P'0EBT0D!`'``<`#!20Q!0B+4`2)$(72=->#
MP`2+4`2)$(72=?3KR8U4)`2XL]`$".@R]?__A<!T)8M$)`0!P`'``P4D,04(
MBU`$B1"%TG37@\`$BU`$B1"%TG7TZ\F-5"0$N+W0!`CH^_3__X7`="6+1"0$
M`<`!P`,%)#$%"(M0!(D0A=)TUX/`!(M0!(D0A=)U].O)C50D!+C'T`0(Z,3T
M__^%P'0EBT0D!`'``<`#!20Q!0B+4`2)$(72=->#P`2+4`2)$(72=?3KR8U4
M)`2X9=`$".B-]/__A<!T)8M$)`0!P`'``P4D,04(BU`$B1"%TG37@\`$BU`$
MB1"%TG7TZ\F-5"0$N-'0!`CH5O3__X7`=`R)PKB]T`0(Z*[V__^-5"0$N.+0
M!`CH./3__X7`=`R)PKCTT`0(Z)#V__^-5"0$N/_0!`CH&O3__XG"A<!T++A<
MT`0(Z'+V__^Z*]$$"+B7T`0(Z&/V__^+1"0L92L%%````'53@\0T7E_#C50D
M!+@/T00(Z-KS__^%P'0.B<*XL]`$".@R]O__Z[Z!?"0;4$%27W6T@7PD'T-,
M14%UJF:!?"0C3CUUH8U4)"6XL]`$".@%]O__ZY'H1^3__X/L'&6A%````(E$
M)`RA_#`%"(/X_W01BU0D#&4K%10```!U,X/$',.-5"0(N+/0!`CH8//__X7`
M=!D/M@`\,`^5PH3`#Y7`#[;`(="C_#`%".O$,<#K]>CKX___@^P<Z&/C__^)
M!"3H.^/__X7`=`*+`(/$',-75E.#[#"+="1`9:$4````B40D+#'`C50D*+BI
MT00(Z/SR__^%P'0'B<.`.`!U(XM$)"QE*P44````#X6;````B?*XJ=$$"(/$
M,%M>7^DV]?__B70D!(D$).A#X___A<!T%(M$)"QE*P44````=6R#Q#!;7E_#
MB30DZ)/B__^)QXD<).B)XO__`<>#QP*)/"3H'./__XG'B5PD&,=$)!1RT`0(
MB70D$,=$)`Q?T00(QT0D"/_____'1"0$`0```(D$).B*X___BT0D+&4K!10`
M``!U!XGZZ6?___^-M@````#HZ^+__U575E.![)R!``"+O"2P@0``9:$4````
MB80DC($``#'`QX0DO````#31!`C'A"3`````6M`$",>$),0`````````QX0D
MV````.W0!`C'A"3<````.=$$",>$).`````*T00(QX0DY````$'1!`C'A"3H
M`````````,>$),@```!%T00(QX0DS````$K1!`C'A"30`````````(U4)%RX
M7-`$".B3\?__A<!T"8`X``^%+P0``.BRX?__B00DZ(KA__^%P`^$\P$``(L8
MA=L/A.D!``")'"3H4.'__P'`@\`!B00DZ./A__^)Q0^V`XGNA,!T-`^VP(E$
M)!#'1"0,4]$$",=$)`C_____QT0D!`$```")+"3H4>+__X/#`8/%`@^V`X3`
M=<R-K"38````N/30!`CK"H/%!(M%_(7`="R-5"1<Z/+P__^)PX7`=.>`.`!T
MXNB*\?__A<"0=-B)'"3H5N+__XG%A<!U+XV<)+P```"+*X7M="*`?0``#X0S
M`0``B>CH6?'__X7`#X4*`0``@\,$BRN%[77>B2PDZ(G@__^)PXDT).A_X/__
M`<.!PP0$``")'"3H#^'__XE$)#2)="0<QT0D&%C1!`C'1"04=-`$"(EL)!#'
M1"0,7=$$",=$)`C_____QT0D!`$```")QHD$).AQX?__QT0D!,`!``")-"3H
M8=[__X/X_W40Z#?>__^+`(/X$0^%D`(``(U$)%R)1"0$BT0D-(D$).CHX/__
MB<:%P'44BT0D;"4`\```/0!````/A,D```"+1"0TB40D$(L'B40D#,=$)`A`
MT@0(QT0D!`$```"A(#$%"(D$).A3WO__,=N+A"2,@0``92L%%`````^%J@@`
M`(G8@<2<@0``6UY?7<.)+"3H&.'__XG%@\,$A<`/A,+^___IY?[__S'MZ=[^
M__^-M"3(````BP:%P'0;C50D7.AH[___A<!T!8`X`'4H@\8$BP:%P'7EQP0D
M#0```.C;W___B<6)QKLMT00(N%,```#I\/W__XD$).BPX/__B<.%P'3*Z;W]
M__^+;"1TZ$S?__\YQ0^%)O___XM$)&PE_P$``#W``0``#X42____B1PDZ(C?
M__^)PXU4)%RX9M$$".CG[O__A<`/A,(!``")!"3H6.#__XE$)`2+!XD$).@J
M]?__B<6%P`^$H@$``(DL).BHWO__B<*#^`-V-<=$)`1KT00(C4#\B50D.`'H
MB00DZ$C@__^%P'48BU0D.(/Z!`^$\@4``(!\%?LO#X3G!0``H?PP!0B#^/\/
MA,L#``"%P`^$60$``+HKT00(N+/0!`CHOO#__^ARW/__QT0D'*G1!`B)1"08
MQT0D%'30!`B+?"0TB7PD$,=$)`R$T00(QT0D"/_____'1"0$`0```(D<).A&
MW___ZT[H']S__X,X$759@\8!Z"+<___'1"0@J=$$"(ET)!R)1"08QT0D%'30
M!`B)?"00QT0D#)+1!`C'1"0(_____\=$)`0!````B1PDZ/;>___'1"0$P`$`
M`(D<).CFV___@_C_=)V+1"0TB00DZ/7<__^)VKA<T`0(Z`#P__^)'"3H</K_
M_^G+_?__B40D%(M$)#2)1"00BP>)1"0,QT0D"`32!`C'1"0$`0```*$@,04(
MB00DZ.W;___IE?W__XD$)(E$)#3H*_K__XN4)(R!``!E*Q44````BT0D-`^%
M,08``(F$)+"!``"!Q)R!``!;7E]=Z9[>__^++^E7_O__QP7\,`4(`````,=$
M)`0`````B2PDZ'W;__^)1"1`A<`/A(O^___'1"0,`@```,=$)`3N____QT0D
M"/____^)QXD$).AOWO__QT0D"`8```"-A"2,`0``B40D!(D\).CDV___@+PD
MC`$```!U#H"\)(T!``!##X1J!```QT0D#`````#'1"0$`````,=$)`@`````
MBT0D0(D$).@8WO__QX0D[`````$C16?'A"3P````B:O-[\>$)/0```#^W+J8
MQX0D^````'94,A#'A"3\````\.'2P\>$)``!````````QX0D!`$```````#'
MA"1(`0```````,=$)#@`````QT0D/`````")7"1,QT0D"`"```"-A"2,`0``
MB40D!(M$)$")!"3H'=O__XG%A<`/CI,!``"-1"T``<`!P(M,)#PQT@'(#Y+"
MB40D/(/Z`8-<)#C_BTPD.(F$)``!``")Z,'H'0'!B4PD.(F,)`0!``"+E"1(
M`0``C;0DC`$``(72#X6&````@_T_?E:)\XU%P(UN0(G"@^+``=6)="1$B40D
M2+D0````C;PD"`$``(G>\Z6-A"3L````Z`G@__^#PT`YZW7=BW0D1(M$)$B)
MPL'J!HU*`<'A!@'.P>(&*=")Q<=$)`Q$````B6PD"(ET)`2-A"0(`0``B00D
MZ#?:__^)K"1(`0``Z?_^__^^0````"G6.>Z)\`]/Q8V,)`@!```!T8G"B<^-
MM"2,`0``@_@$<W/VP@)T`F:E@^(!=`&DBY0D2`$```'"B90D2`$``(/Z0`^$
M]@$``(N$)``!``")1"0\BX0D!`$``(E$)#CIE_[__XU4)%RXL]`$".B4ZO__
MA<`/A';]__\/M@"$P`^5PCPP#Y7`#[;`(="C_#`%".D#_/__]L$!#X4R`P``
M]\<"````#X42`P``B='!Z0+SI>EL____BUPD3(M$)$")!"3HH-K__XM$)#S!
MZ`.#X#^-2`'&A`0(`0``@(V$)`@!``"-/`B#^3@/CKX!``"Z0````"G*=",Q
MP/;"`70,Q@<`N`$````YT',0Q@0'`,9$!P$`@\`".=!R\(V$).P```#HD-[_
M_[D.````,<"-O"0(`0``\ZN+1"0X#\B)A"1``0``BT0D/`_(B80D1`$``(V$
M).P```#H6M[__XN$).P````/R(F$)$\!``"+A"3P````#\B)A"13`0``BX0D
M]`````_(B80D5P$``(N$)/@````/R(F$)%L!``"+A"3\````#\B)A"1?`0``
MC:PD3P$``(V\)&,!``")_@^V10")1"00QT0D#%/1!`C'1"0(_____\=$)`0!
M````B3PDZ%+:__^#Q0&#QP(Y]77.QH0DBP$```#'1"0<J=$$"(V$)&,!``")
M1"08QT0D%'30!`B+1"0TB40D$,=$)`QUT00(QT0D"/_____'1"0$`0```(D<
M).C]V?__Z1?[__\IQ8V,)(P!``"--`&-A"3L````Z&#=__^+A"0``0``B40D
M/(N$)`0!``")1"0XZ03]__^+?P2%_P^$#OK__XD\).ARV/__@_@##X;]^?__
MQT0D!'#1!`B#Z`0!^(D$).@4VO__A<`/1._IWOG__[HX````*<HQP(/Z!`^#
MH0```/;"`G0"9JN#X@$/A&C^__^JZ6+^__^`O"2.`0``00^%B/O__X"\)(\!
M``!##X5Z^___@+PDD`$``$@/A6S[__^`O"21`0``10^%7OO__\=$)`P"````
MQT0D!,;____'1"0(_____XM\)$")/"3H=MG__\=$)`@I````C80DC`$``(E$
M)`2)/"3HZ];__\=$)!RIT00(C80DC`$``.FF_O__]\<!````#X6/````]\<"
M````=7V#^@0/@D+___^)U8/E_(U-_\'I`H/A`8G.B0>Y!````#GI<QZ%]G0,
MB4<$N0@````YZ7,.B00/B40/!(/!"#GI<O(!S^D"____#[<.9HD/@\<"@\8"
M@^H"Z=K\__\/MI0DC`$``(A4)#B($8/'`8VT)(T!``"-4/_IKOS__V:K@^H"
MZ7G___^J@^H!Z6C____HKM?__U575E.#[#QEH10```")1"0L,<"+-?`O!0AE
MBQX/MD-DB$-EC50D*+B7T`0(Z,SF__^%P'0)@#@Q#X1Y`@``Z,'O__]EBQ['
M1"0,"P```,=$)`@!````QT0D!*/1!`B)'"3HF-7__X7`#X1!`@``BT`,BT`8
MB40D'&6++H,]2$$%"`$/CIH````QV^M*QT0D#`(```#'1"0(`````(E4)`2)
M+"3H)MC__V6++HE$)`2->P&A1$$%"(L$N(D$).CLU___B<&A2$$%"(7)=4J#
MPP(YV(G[?D''1"0,`````(E<)`B+1"0<B40D!(DL).A,UO__A<!T&8L098LN
MBT(()0`$(``]``0``'6"BT(,ZYRA2$$%"&6++HU0_SG3#X0T`0``QT0D#`,`
M``#'1"0(`0```,=$)`2HT00(B2PDZ+S4__^)PX7`="O'1"0(JM$$"(M`#(L`
MB40D!&6+!HD$).BJU/__BT,,BP#V0`I`#X5I`0``QT0D#`,```#'1"0(`0``
M`,=$)`2OT00(98L&B00DZ&C4__^)PX7`="Z-5"0HN&70!`CH4^7__X7`#X04
M`0``B40D"(M##(L`B40D!&6+!HD$).A$U/__QT0D"`$```#'1"0$L=$$"&6+
M!HD$).AIT___QT0D",;1!`B)1"0$98L&B00DZ!+4__]EBP;&0&4`C50D*+A<
MT`0(Z.SD__^)PZ-,004(A<!T:\=$)`3``0``B1PDZ`+3__^-4`&#^@%V"8/X
M$0^%N````(M$)"QE*P44````#X6B````@\0\6UY?7<.#^`$/CL/^__^[`0``
M`(M$)!R)1"0$B2PDZ'K3__^#PP%EBRXY'4A!!0A_XNF;_O__H41!!0B)!"3H
M+_+__XG#HTQ!!0B%P`^%>?___\<$))32!`CH7]7__V6++NEK_O__@'@!``^$
MA?W__^EX_?__H41!!0B+$(M##(L`Z&+H___I[O[__XE$)`1EBP:)!"3HL]3_
M_^F#_O__Z+G4__^)1"0,B5PD"*%$004(BP")1"0$QP0DN-($".CZU/__5U93
M@^P@BW0D,&6A%````(E$)!PQP(DT).@2[/__#[80B<.$TG00@\`!@/HO#T38
M#[80A-)U\*'\,`4(A?8/E<&)SX/X_W1>A<`/E<(A^H32=1B+1"0<92L%%```
M``^%A````(/$(%M>7\.`/@!TX\=$)`@$````QT0D!%C1!`B)'"3HLM3__X7`
M=<>+1"0<92L%%````'5/B?"#Q"!;7E_I9.3__XU4)!BXL]`$".@UX___A<!T
M(0^V$(#Z,`^5P(32#Y7"(=")^B'"#[;`H_PP!0CI=O___\<%_#`%"`````#I
M:____^BMT___4X/L&.@4U___@</(8```BX,$`0``B40D#(M$)"B)1"0(BT0D
M)(E$)`2+1"0@B00DZ)C1__^#Q!A;PP```%.#[`CHU];__X'#BV```(/$"%O#
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````#`````0`"`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z
M.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E
M:2\E<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$52
M3$Q)0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%7
M3D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?
M1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,
M7U1%35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`4UE35$5-`"]T
M;7``5$5-4$1)4@!435``55-%4@!54T523D%-10`E,#)X`'!A<BT`)7,E<R5S
M)7,`4$%42`!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E
M<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`#``4$%2.CI086-K97(Z
M.E9%4E-)3TX`,2XP-#4`+64`+2T```!?7T5.5E]005)?0TQ%04Y?7R`@("`@
M("`@("`@("`@(`````!P97)L>'-I+F,````E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@
M<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M
M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!5;F%B;&4@=&\@
M8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*
M`````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")]
M)PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G
M92!?7W!A<E]P;#L*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL
M92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE
M.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z
M.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E
M;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R
M;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`[
M"FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D
M=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L
M"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&
M1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A
M+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@
M)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R
M96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@
M)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N
M86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@
M,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P
M87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@
M*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z
M.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4
M.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM0
M05)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/
M(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>
M3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*
M7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@
M)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY
M("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]705).
M7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S
M=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1P<F]G
M;F%M93L*;7D@)&]F9G-E="`](#4Q,CL*;7D@)&ED>"`]("TQ.PIW:&EL92`H
M,2D*>PHD;V9F<V5T(#T@)'-I>F4@:68@)&]F9G-E="`^("1S:7IE.PIS965K
M(%]&2"P@+21O9F9S970L(#(@;W(@9&EE('%Q6W-E96L@9F%I;&5D(&]N("(D
M<')O9VYA;64B.B`D(5T["FUY("1N<F5A9"`](')E860@7T9(+"`D8G5F+"`D
M;V9F<V5T.PID:64@<7%;<F5A9"!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A
M72!U;FQE<W,@)&YR96%D(#T]("1O9F9S970["B1I9'@@/2!R:6YD97@H)&)U
M9BP@(EQN4$%2+G!M7&XB*3L*;&%S="!I9B`D:61X(#X](#`@?'P@)&]F9G-E
M="`]/2`D<VEZ92!\?"`D;V9F<V5T(#X@,3(X("H@,3`R-#L*)&]F9G-E="`J
M/2`R.PI]"FQA<W0@=6YL97-S("1I9'@@/CT@,#L*)&]F9G-E="`M/2`D:61X
M("T@-#L*<V5E:R!?1D@L("TD;V9F<V5T+"`R.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<V5E:R!?1D@L("TD;V9F<V5T("T@=6YP86-K*").(BP@)&)U9BDL(#([
M"G)E860@7T9(+"`D8G5F+"`T.PHD9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@
M-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI;&4@*"1B=68@97$@(D9)3$4B*2![
M"G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").
M(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7$H56YP86-K
M:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]("@@)&9U;&QN
M86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@
M*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<
M+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N
M<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A
M?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W1E
M;7!F:6QE*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H
M("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&)A<V5N
M86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N86UE
M7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*)%!!
M4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D
M8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A
M9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E
M;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A
M)&UO9'5L93L*;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[
M)&UO9'5L97T@?'P@9&\@>PIM>2`D:V5Y.PIF;W)E86-H("AK97ES("5R97%U
M:7)E7VQI<W0I('L*;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B1K97D@
M/2`D7SL@;&%S=#L*?0ID96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D
M969I;F5D*"1K97DI.PI](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O
M;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.
M?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP
M<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*<V5E:R@D9F@L(#`L(#`I.PIR
M971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H
M(B1F:6QE;F%M92T^>V-R8WTN<&TB+"`D9FEL96YA;64M/GMB=69]*3L*;W!E
M;B!M>2`D9F@L("<\)RP@)&9I;&5N86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D
M9FEL96YA;64Z("0A(CL*8FEN;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I
M92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A
M7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z
M.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R
M.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U
M:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y
M<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE
M?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]
M?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID
M;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ
M95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T[
M"GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P
M;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T
M+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[
M4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E
M8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%
M0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M
M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@
M8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R
M"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD
M("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM0
M05)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA
M;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6
M*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R
M(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#([
M"GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF
M("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF
M("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I
M('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B
M=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`]
M(#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@
M)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PI]"F5L<VEF
M("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'
M5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.
M5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z
M.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF
M="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER
M92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'!A<B`]
M('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PI!
M<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@Q,C@J,3`R-"D["F]P96X@;7D@
M)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A
M(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@
M9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R![
M"FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!
M+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S
M+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]
M"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!0
M05(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I
M.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E
M<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]
M($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)
M3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W
M-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@
M)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L
M(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?
M5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*?0IF;W)E86-H(&UY
M("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E]
M(&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO
M.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R([
M"FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D
M97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H
M;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT
M*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E
M(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P
M('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(*
M*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E9FEL
M97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O
M8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#
M;VYF:6=[;&EB7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME
M>7,@)69I;&5S*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D
M:7(@*$!I;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER
M7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D
M,BD["FQA<W0["GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI
M7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE
M>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*
M96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I
M<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D
M;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H
M)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@
M:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN
M86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E
M9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92![
M"F]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I
M;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L
M;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<
M)&-O;G1E;G0L("1F:6QE*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D
M;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C
M:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I
M.PI]"F]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B1F:"T^<')I;G0H
M(D9)3$4B*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K
M(#DI*3L*)&9H+3YP<FEN="AS<')I;G1F*`HB)3`X>"\E<R(L($%R8VAI=F4Z
M.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64**2D["B1F:"T^
M<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*)&9H+3YP<FEN
M="@D8V]N=&5N="D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I
M(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P
M+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H
M)&]U="DI6SE=*2!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z
M.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D
M<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@
M?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S
M:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@
M*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\
M)&]U="(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC
M;&]S92@D9F@I.PI]"GT*)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X
M9&EG97-T(#H@)&UT:6UE.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@
M+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B
M.PHD9F@M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.
M)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H
M(EQN4$%2+G!M7&XB*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*
M97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I
M>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!
M<F-H:79E.CI::7`["GT*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PIM
M>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PHD9F@M/F9D;W!E;BAF:6QE;F\H7T9(
M*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B1Z:7`M/G)E861&<F]M1FEL94AA
M;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I
M(&]R(&1I92`B)"$Z("1`(CL*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*
M)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D
M14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%
M3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@
M>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D
M;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI
M<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA
M;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O
M"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#
M;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?
M;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL
M92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S
M=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I
M*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@
M86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U
M=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M
M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I
M.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]
M"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID
M:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R
M(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R
M86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%
M3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%2
M1U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U
M:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X
M="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG
M*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P
M871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R
M;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I
M<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC
M=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A
M<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E
M($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E
M8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@
M24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S
M<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@4$%2.PIR
M97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U
M:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q
M=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ
M56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M
M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!0
M97)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B
M(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q
M.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL
M('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ
M=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@
M)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE
M.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF
M(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE
M*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@
M*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E
M('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\
M?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP
M9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L
M("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[
M4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;
M.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["G-E96L@)&9H
M+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PII9B`H)&)U9B!E
M<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*<WES<F5A9"`D9F@L
M("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D0V]N
M9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*?0IE;'-E('L*;7D@)&-T>"`]
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W
M*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z
M.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$
M:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D
M1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N
M(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M
M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*
M:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["F)I
M;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]
M"GT*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C
M='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*?0IC;&]S92@D9F@I
M.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B
M)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D
M<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T
M96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!]
M(#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*;7D@*"1N86UE+"`D8V]N
M=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP
M+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE
M(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@)&9H+"`G/B<L("1T96UP;F%M
M92!O<B!D:64@(F-A;B=T('=R:71E("1T96UP;F%M93H@)"$B.PIB:6YM;V1E
M("1F:#L*<')I;G0@)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D
M;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M
M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T
M=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I
M;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345]
M(#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]
M("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@
M)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P
M<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K
M(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G
M;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F
M:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H
M+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D
M0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P
M;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE
M>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[
M4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL*
M*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#
M;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I
M<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I
M<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G
M;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T[
M"FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2![
M"B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM
M>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D
M*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W
M9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_
M/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM
M?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A
M<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@
M,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@
M/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(
M12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PID96QE=&4@)$5.5GLG4$%2
M7R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I
M('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I
M9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L
M96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@
M*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*
M96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D
M=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.
M(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?
M0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T
M.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92![
M"G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N
M9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O
M;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE
M>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]
M"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"90
M05(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7$H
M<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.
M;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O9VYA
M;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?
M5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T52
M4D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)2
M3U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I
M9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@`!&P,[T````!D```#PD/__+`$`
M`-"4__^0!0``T);__^P````"E___&`$``*"7__]0`0``[Z+__Y0!``"7H___
M_`$``!"D__\D`@``5Z7__V0"```KI___I`(``.BG___D`@``3:C__P@#``!\
MJ/__(`,``$NI__]8`P``4*G__VP#```6J___K`,``#:K___``P``]JO__P`$
M``!9K___,`0``+6O__],!```SZ___V0$``"UL/__K`0``/*[__\(!0``!K__
M_T@%``#SO___P`4``!0``````````7I2``%\"`$;#`0$B`$'"!`````<````
MW)7__S(`````````%``````````!>E(``7P(`1L,!`2(`0``$````!P```#B
ME?__`0`````````@````,````+R/___@`P````X(1@X,2@\+=`1X`#\:.RHR
M)")`````5````$B6__]/"P```$$."(4"00X,AP-!#A"&!$$.%(,%1@Z0`P,[
M"PH.%$'##A!!Q@X,0<<."$'%#@1!"P```&0```"8````4Z'__Z@`````00X(
MA0)!#@R'`T$.$(8$00X4@P5##D`"6@H.%$'##A!!Q@X,0<<."$'%#@1!"W$*
M#A1!PPX00<8.#$''#@A!Q0X$00M'#A1!PPX00<8.#$''#@A!Q0X$)``````!
M``"3H?__>0````!!#@B#`D8.D`$":PH."$'##@1!"P```#P````H`0``Y*'_
M_T<!````00X(A0)!#@R'`T$.$(8$00X4@P5&#K`!=`H.%$'##A!!Q@X,0<<.
M"$'%#@1!"P`\````:`$``.NB___4`0```$$."(4"00X,AP-!#A"&!$$.%(,%
M0PY0`NX*#A1!PPX00<8.#$''#@A!Q0X$00L`/````*@!``!_I/__O0````!!
M#@B%`D$.#(<#00X0A@1!#A2#!48.P"`"<0H.%$'##A!!Q@X,0<<."$'%#@1!
M"R````#H`0``_*3__V4`````00X(@P)##C`"7PX(0<,.!````!0````,`@``
M/:7__R\`````0PX@:PX$`#0````D`@``5*7__\\`````00X(AP)!#@R&`T$.
M$(,$1@[`0`*?"@X00<,.#$'&#@A!QPX$00L`$````%P"``#KI?__!0``````
M```\````<`(``-RE___&`0```$$."(4"00X,AP-!#A"&!$$.%(,%1@[`(0)K
M"@X40<,.$$'&#@Q!QPX(0<4.!$$+$````+`"``!BI___(``````````\````
MQ`(``&ZG___``````$$."(,"0PX@`HP*#@A!PPX$00M+"@X(0<,.!$4+4`H.
M"$'##@1%"T4."$'##@0`+`````0#``#NI___8P,```!!#@B'`D$.#(8#0PY`
M`PD#"@X,0<8."$''#@1!"P``&````#0#```AJ___7`````!##B!D"@X$00L`
M`!0```!0`P``8:O__QH`````0PX@5@X$`$0```!H`P``8ZO__^8`````00X(
MAP)!#@R&`T$.$(,$0PY``D0*#A!!PPX,0<8."$''#@1%"V`*#A!!PPX,0<8.
M"$''#@1!"U@```"P`P```:S__ST+````00X(A0)!#@R'`T$.$(8$00X4@P5&
M#K"#`@.,`@H.%$'##A!!Q@X,0<<."$'%#@1!"P-Y`@H.%$'##A!!Q@X,0<<.
M"$'%#@1%"P``/`````P$``#BMO__%`,```!!#@B%`D$.#(<#00X0A@1!#A2#
M!4,.4`-*`@H.%$'##A!!Q@X,0<<."$'%#@1!"T0```!,!```MKG__^T`````
M00X(AP)!#@R&`T$.$(,$0PXP`F$*#A!!PPX,0<8."$''#@1!"W,*#A!!PPX,
M0<8."$''#@1%"RP```"4!```.(____T!````00X(A0)"#05)AP.&!(,%`UH!
M"L-!QD''0<4,!`1!"QP```#$!```*[K__SH`````00X(@P)##B!T#@A!PPX$
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````,:F!`BFI@0(```````````````````````````!````
MY@(```$```#X`@```0````(#```!````#`,```\```!R!```#`````"@!`@-
M````8,\$"!D```#(+@4(&P````0````:````S"X%"!P````$````]?[_;T""
M!`@%````\(@$"`8````P@P0("@```*D$```+````$````!4``````````P``
M`/0O!0@"````Z`$``!0````1````%P```!2/!`@1````Y(X$"!(````P````
M$P````@```#^__]O5(X$"/___V\!````\/__;YJ-!`@`````````````````
M`````````````````````````````````````````````````````````.0N
M!0@``````````#:@!`A&H`0(5J`$"&:@!`AVH`0(AJ`$"):@!`BFH`0(MJ`$
M",:@!`C6H`0(YJ`$"/:@!`@&H00(%J$$"":A!`@VH00(1J$$"%:A!`AFH00(
M=J$$"(:A!`B6H00(IJ$$"+:A!`C&H00(UJ$$".:A!`CVH00(!J($"!:B!`@F
MH@0(-J($"$:B!`A6H@0(9J($"':B!`B&H@0(EJ($"*:B!`BVH@0(QJ($"-:B
M!`CFH@0(]J($"`:C!`@6HP0()J,$"#:C!`A&HP0(5J,$"&:C!`AVHP0(AJ,$
M"):C!`BFHP0(MJ,$",:C!`C6HP0(YJ,$"/:C!`@``````````/_____\T@0(
M1T-#.B`H4$Q$+4QI;G5X*2`Q,RXS+C`@,C`R-#`U,C$@*')E;&5A<V4I```N
M<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N8G5I;&0M:60`+FYO=&4N9VYU
M+G!R;W!E<G1Y`"YN;W1E+D%"22UT86<`+F=N=2YH87-H`"YD>6YS>6T`+F1Y
M;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`+G)E
M;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R
M`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9&%T82YR96PN
M<F\`+F1Y;F%M:6,`+F=O=``N9V]T+G!L=``N9&%T80`N8G-S`"YC;VUM96YT
M```````````````````````````````````````````````````````+````
M`0````(```"T@00(M`$``!,```````````````$`````````$P````<````"
M````R($$",@!```D```````````````$`````````"8````'`````@```.R!
M!`CL`0``-```````````````!``````````Y````!P````(````@@@0((`(`
M`"````````````````0`````````1P```/;__V\"````0(($"$`"``#P````
M!@`````````$````!````%$````+`````@```#"#!`@P`P``P`4```<````!
M````!````!````!9`````P````(```#PB`0(\`@``*D$``````````````$`
M````````80```/___V\"````FHT$")H-``"X````!@`````````"`````@``
M`&X```#^__]O`@```%2.!`A4#@``D`````<````!````!`````````!]````
M"0````(```#DC@0(Y`X``#`````&``````````0````(````A@````D```!"
M````%(\$"!0/``#H`0``!@```!@````$````"````(\````!````!@````"@
M!`@`(```(```````````````!`````````"*`````0````8````@H`0(("``
M`.`#`````````````!`````$````E0````$````&`````*0$"``D``!=*P``
M```````````0`````````)L````!````!@```&#/!`A@3P``%```````````
M````!`````````"A`````0````(`````T`0(`%```#`_``````````````0`
M````````J0````$````"````,`\%"#"/``#4```````````````$````````
M`+<````!`````@````00!0@$D```$`4`````````````!`````````#!````
M#@````,```#(+@4(R)X```0```````````````0````$````S0````\````#
M````S"X%",R>```$```````````````$````!````-D````!`````P```-`N
M!0C0G@``$P``````````````!`````````#F````!@````,```#D+@4(Y)X`
M``@!```'``````````0````(````[P````$````#````["\%".R?```(````
M```````````$````!````/0````!`````P```/0O!0CTGP````$`````````
M````!`````0```#]`````0````,```#T,`4(]*```!````````````````0`
M`````````P$```@````#````(#$%"`2A```T$``````````````@````````
M``@!```!````,``````````$H0``*P```````````````0````$````!````
D`P``````````````+Z$``!$!``````````````$`````````
